
{% extends "base.html" %}

{% block title %}{{ SITENAME }} - Authors{% endblock %}

{% block content %}
    <h1>Authors on {{ SITENAME }}</h1>

    <ul>
    {%- for author, articles in authors|sort %}
        <li><a href="{{ SITEURL }}/{{ author.url }}">{{ author }}</a> ({{ articles|count }})</li>
    {% endfor %}
    </ul>
{% endblock %}

