
{% if DEFAULT_PAGINATION %}
<p class="paginator">
    {% if articles_page.has_previous() %}
        <a href="{{ SITEURL }}/{{ articles_previous_page.url }}">&laquo;</a>
    {% endif %}
    Page {{ articles_page.number }} / {{ articles_paginator.num_pages }}
    {% if articles_page.has_next() %}
        <a href="{{ SITEURL }}/{{ articles_next_page.url }}">&raquo;</a>
    {% endif %}
</p>
{% endif %}

